@@ -18,13 +18,12 @@
 
 #include <kopetecontact.h>
 
-
 #include <QPointer>
-#include <kdebug.h>
-#include <kaction.h>
+#include "jabber_protocol_debug.h"
+#include <QAction>
 #include <kselectaction.h>
-#include <klocale.h>
-#include <kicon.h>
+#include <KLocalizedString>
+#include <QIcon>
 
 #include "tasks/jt_privatestorage.h"
 #include "ui/dlgjabberbookmarkeditor.h"
@@ -102,7 +101,7 @@ void JabberBookmarks::accountConnected()
 		return;
 	
 	JT_PrivateStorage * task = new JT_PrivateStorage ( m_account->client()->rootTask ());
-	task->get( "storage" , "storage:bookmarks" );
+	task->get( QStringLiteral("storage") , QStringLiteral("storage:bookmarks") );
 	QObject::connect ( task, SIGNAL (finished()), this, SLOT (slotReceivedBookmarks()) );
 	task->go ( true );
 }
@@ -110,20 +109,20 @@ void JabberBookmarks::accountConnected()
 JabberBookmark::List JabberBookmarks::bookmarksFromStorage( const QDomElement &storageElement )
 {
 	JabberBookmark::List bookmarks;
-	if ( !storageElement.isNull() && storageElement.tagName() == "storage" ) {
+	if ( !storageElement.isNull() && storageElement.tagName() == QLatin1String("storage") ) {
 		for ( QDomElement element = storageElement.firstChildElement(); !element.isNull(); element = element.nextSiblingElement() ) {
 
-			if ( element.tagName() == "conference" ) {
+			if ( element.tagName() == QLatin1String("conference") ) {
 				JabberBookmark bookmark;
 
-				bookmark.setJId( element.attribute( "jid" ) );
-				bookmark.setName( element.attribute( "name" ) );
-				bookmark.setAutoJoin( element.attribute( "autojoin", "false" ) == "true" );
+				bookmark.setJId( element.attribute( QStringLiteral("jid") ) );
+				bookmark.setName( element.attribute( QStringLiteral("name") ) );
+				bookmark.setAutoJoin( element.attribute( QStringLiteral("autojoin"), QStringLiteral("false") ) == QLatin1String("true") );
 
 				for ( QDomElement childElement = element.firstChildElement(); !childElement.isNull(); childElement = childElement.nextSiblingElement() ) {
-					if ( childElement.tagName() == "nick" ) {
+					if ( childElement.tagName() == QLatin1String("nick") ) {
 						bookmark.setNickName( childElement.text() );
-					} else if ( childElement.tagName() == "password" ) {
+					} else if ( childElement.tagName() == QLatin1String("password") ) {
 						bookmark.setPassword( childElement.text() );
 					}
 				}
@@ -138,27 +137,27 @@ JabberBookmark::List JabberBookmarks::bookmarksFromStorage( const QDomElement &s
 
 QDomElement JabberBookmarks::bookmarksToStorage( const JabberBookmark::List &bookmarks, QDomDocument &document )
 {
-	QDomElement storageElement = document.createElement( "storage" );
-	storageElement.setAttribute( "xmlns", "storage:bookmarks" );
+	QDomElement storageElement = document.createElement( QStringLiteral("storage") );
+	storageElement.setAttribute( QStringLiteral("xmlns"), QStringLiteral("storage:bookmarks") );
 
 	foreach ( const JabberBookmark &bookmark, bookmarks ) {
-		QDomElement conferenceElement = document.createElement( "conference" );
-		conferenceElement.setAttribute( "jid", bookmark.jId() );
+		QDomElement conferenceElement = document.createElement( QStringLiteral("conference") );
+		conferenceElement.setAttribute( QStringLiteral("jid"), bookmark.jId() );
 
 		if ( !bookmark.name().isEmpty() )
-			conferenceElement.setAttribute( "name", bookmark.name() );
+			conferenceElement.setAttribute( QStringLiteral("name"), bookmark.name() );
 
 		if ( bookmark.autoJoin() )
-			conferenceElement.setAttribute( "autojoin", "true" );
+			conferenceElement.setAttribute( QStringLiteral("autojoin"), QStringLiteral("true") );
 
 		if ( !bookmark.nickName().isEmpty() ) {
-			QDomElement element = document.createElement( "nick" );
+			QDomElement element = document.createElement( QStringLiteral("nick") );
 			element.appendChild( document.createTextNode( bookmark.nickName() ) );
 			conferenceElement.appendChild( element );
 		}
 
 		if ( !bookmark.password().isEmpty() ) {
-			QDomElement element = document.createElement( "password" );
+			QDomElement element = document.createElement( QStringLiteral("password") );
 			element.appendChild( document.createTextNode( bookmark.password() ) );
 			conferenceElement.appendChild( element );
 		}
@@ -194,7 +193,6 @@ void JabberBookmarks::slotReceivedBookmarks( )
 	}
 }
 
-
 void JabberBookmarks::insertGroupChat(const XMPP::Jid &jid)
 {
 	bool containsConference = false;
@@ -215,7 +213,7 @@ void JabberBookmarks::insertGroupChat(const XMPP::Jid &jid)
 
 	m_bookmarks.append( bookmark );
 
-	QDomDocument document( "storage" );
+	QDomDocument document( QStringLiteral("storage") );
 	const QDomElement element = bookmarksToStorage( m_bookmarks, document );
 
 	JT_PrivateStorage *task = new JT_PrivateStorage( m_account->client()->rootTask() );
@@ -223,7 +221,7 @@ void JabberBookmarks::insertGroupChat(const XMPP::Jid &jid)
 	task->go( true );
 }
 
-KAction * JabberBookmarks::bookmarksAction(QObject *parent)
+QAction * JabberBookmarks::bookmarksAction(QObject *parent)
 {
 	Q_UNUSED( parent )
 
@@ -238,7 +236,7 @@ KAction * JabberBookmarks::bookmarksAction(QObject *parent)
 	}
 
 	KSelectAction *action = new KSelectAction( this );
-	action->setIcon( KIcon( "jabber_group" ) );
+    action->setIcon( QIcon::fromTheme(QStringLiteral("jabber_group")) );
 	action->setText( i18n( "Groupchat Bookmark" ) );
 	action->setItems( menuEntries );
 
@@ -259,7 +257,7 @@ void JabberBookmarks::slotJoinChatBookmark( const QString & _jid )
 		if ( editor->exec() && editor ) {
 			m_bookmarks = editor->bookmarks();
 
-			QDomDocument document( "storage" );
+			QDomDocument document( QStringLiteral("storage") );
 			const QDomElement element = bookmarksToStorage( m_bookmarks, document );
 
 			JT_PrivateStorage *task = new JT_PrivateStorage( m_account->client()->rootTask() );
@@ -270,4 +268,3 @@ void JabberBookmarks::slotJoinChatBookmark( const QString & _jid )
 	}
 }
 
-#include "jabberbookmarks.moc"
