@@ -21,13 +21,12 @@
 #include "ssimodifytask.h"
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <qstring.h>
 #include "connection.h"
 #include "oscarutils.h"
 #include "transfer.h"
 
-
 SSIModifyTask::SSIModifyTask( Task* parent, bool staticTask ) : Task( parent )
 {
 	m_ssiManager = parent->client()->ssiManager();
@@ -37,7 +36,6 @@ SSIModifyTask::SSIModifyTask( Task* parent, bool staticTask ) : Task( parent )
 	m_id = 0;
 }
 
-
 SSIModifyTask::~SSIModifyTask()
 {
 }
@@ -297,7 +295,6 @@ void SSIModifyTask::handleContactAck()
 		}
 	};
 
-
 }
 
 void SSIModifyTask::sendContactUpdate()
@@ -420,7 +417,6 @@ void SSIModifyTask::changeGroupOnServer()
 		oldGroupItem.setTLVList( list );
 	}
 
-
 	//Change the 0x00C8 TLV in the new group item to add the bid we're
 	//adding to this group
 	QList<TLV> list2 = m_groupItem.tlvList();
@@ -642,4 +638,3 @@ void SSIModifyTask::handleContactRemove()
 	}
 }
 
-//kate: tab-width 4; indent-mode csands;
